.. _support:

Support
=======
If you have any questions or issues about Eve, there are several options:

Mailing List
------------
The `mailing list`_ is intended to be a low traffic resource for both
developers/contributors and API maintainers looking for help or requesting
feedback. 

File an Issue
-------------
If you notice some unexpected behavior in Eve, or want to see support for a new
feature, `file an issue on GitHub
<https://github.com/pyeve/eve/issues>`_.

Send a Tweet
------------
If your question is less than 140 characters, feel free to send a tweet to
`@nicolaiarocci <http://twitter.com/nicolaiarocci>`_.

IRC
---
There is an official Freenode channel for Eve at `#python-eve
<irc://irc.freenode.net/python-eve>`_.

.. _`mailing list`: https://groups.google.com/forum/#!forum/python-eve
